==> hive-exec-0.13.1-sources.jar: org/apache/hadoop/hive/ql/exec/vector/expressions/CastDoubleToDecimal.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.vector.expressions;

import org.apache.hadoop.hive.ql.exec.vector.DecimalColumnVector;
import org.apache.hadoop.hive.ql.exec.vector.DoubleColumnVector;

/**
 * Cast input double to a decimal. Get target value scale from output column vector.
 */
public class CastDoubleToDecimal extends FuncDoubleToDecimal {

  private static final long serialVersionUID = 1L;

  public CastDoubleToDecimal() {
    super();
  }

  public CastDoubleToDecimal(int inputColumn, int outputColumn) {
    super(inputColumn, outputColumn);
  }

  @Override
  protected void func(DecimalColumnVector outV, DoubleColumnVector inV, int i) {
    outV.vector[i].update(inV.vector[i], outV.scale);
    outV.checkPrecisionOverflow(i);
  }
}

==> hive-exec-2.0.0-sources.jar: org/apache/hadoop/hive/ql/exec/vector/expressions/CastDoubleToDecimal.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.vector.expressions;

import org.apache.hadoop.hive.common.type.HiveDecimal;
import org.apache.hadoop.hive.ql.exec.vector.DecimalColumnVector;
import org.apache.hadoop.hive.ql.exec.vector.DoubleColumnVector;

/**
 * Cast input double to a decimal. Get target value scale from output column vector.
 */
public class CastDoubleToDecimal extends FuncDoubleToDecimal {

  private static final long serialVersionUID = 1L;

  public CastDoubleToDecimal() {
    super();
  }

  public CastDoubleToDecimal(int inputColumn, int outputColumn) {
    super(inputColumn, outputColumn);
  }

  @Override
  protected void func(DecimalColumnVector outV, DoubleColumnVector inV, int i) {
    String s = ((Double) inV.vector[i]).toString();
    outV.vector[i].set(HiveDecimal.create(s));
  }
}
